;APSFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF

; Copyright 2024 ing. E. Th. van den Oosterkamp
;
; Example software for the book "Classic AmigaOS Programming" (ISBN  9781690195153)
;
; I have also written a tutorial for this example file, which has been
; published here: https://www.edsa.uk/blog/tutorial-a-simple-amigaos-gui-in-assembler 
;
; Permission is hereby granted, free of charge, to any person obtaining a copy 
; of this software and associated files (the "Software"), to deal in the Software 
; without restriction, including without limitation the rights to use, copy,
; modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
; and to permit persons to whom the Software is furnished to do so,
; subject to the following conditions:
;
; The above copyright notice and this permission notice shall be included in 
; all copies or substantial portions of the Software.
;
; THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
; INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
; PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
; HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION 
; OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
; SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



		INCDIR	"AsmInc:"
		INCLUDE	"exec/exec_lib.i"
		INCLUDE "libraries/gadtools.i"
		INCLUDE	"intuition/intuition_lib.i"


;-----------------------------------------------------------------
; GadTools offsets missing from the NDK
		
CreateGadget		EQU	-30
FreeGadgets		EQU	-36
GT_SetGadgetAttrs	EQU	-42
CreateMenus		EQU	-48
FreeMenus		EQU	-54
LayoutMenuItems		EQU	-60
LayoutMenus		EQU	-66
GT_GetIMsg		EQU	-72
GT_ReplyIMsg		EQU	-78
GT_RefreshWin		EQU	-84
GT_BeginRefresh		EQU	-90
GT_EndRefresh		EQU	-96
GT_FilterIMsg		EQU	-102
GT_PostFilterIMsg	EQU	-108
CreateContext		EQU	-114
DrawBevelBox		EQU	-120
GetVisualInfo		EQU	-126
FreeVisualInfo		EQU	-132


;-----------------------------------------------------------------
; Internally used commands

CMD_MASK	EQU	$0FF0
CMD_NONE	EQU	0
CMD_ABOUT	EQU	$10
CMD_OPTIONS	EQU	$20
CMD_OPTHIGH	EQU	CMD_OPTIONS+0
CMD_OPTMID	EQU	CMD_OPTIONS+1
CMD_OPTLOW	EQU	CMD_OPTIONS+2
CMD_QUIT	EQU	$100

SRC_MASK	EQU	$3000
SRC_GADGET	EQU	$1000
SRC_MENU	EQU	$2000



;-----------------------------------------------------------------
;-----------------------------------------------------------------


		; Open libraries we need

Main: 		MOVE.L	4.W,a6			; a6 = ExecBase
		LEA.L	.GadName(PC),a1
		JSR	_LVOOldOpenLibrary(a6)
		MOVE.L	d0,GadBase
		BEQ.B	.NoGad
		LEA.L	.IntName(PC),a1
		JSR	_LVOOldOpenLibrary(a6)
		MOVE.L	d0,IntBase
		BEQ.B	.NoInt

		; Open the window with only a taglist

		BSR.W	OpenWindow
		BEQ.B	.NoWin			; Z-flag set = no window open

		; Get the GadTools VisualInfo

		MOVE.L	GadBase(PC),a6		; a6 = GadBase
		MOVE.L	MainWin(PC),a0		; APTR Window
		MOVE.L	wd_WScreen(a0),a0	; APTR Screen
		SUB.L	a1,a1			; APTR Taglist = null
		JSR	GetVisualInfo(a6)
		MOVE.L	d0,VisualInfo

		; Setup the menu and gadgets

		BSR.W	CreateMenu
		BSR.W	CreateGadgets

		; Start the main message loop

		BSR.W	MainMsgLoop

		; Close the window, free gadeds, menus and visualinfo

		MOVE.L	IntBase(PC),a6		; a6 = IntBase
		MOVE.L	MainWin(PC),a0		; APTR Window
		JSR	_LVOCloseWindow(a6)
		MOVE.L	GadBase(PC),a6		; a6 = GadBase
		MOVE.L	WinGGList(PC),a0	; APTR GadgetList
		JSR	FreeGadgets(a6)
		MOVE.L	WinMenu(PC),a0		; APTR Menu
		JSR	FreeMenus(a6)
		MOVE.L	VisualInfo(PC),a0
		JSR	FreeVisualInfo(a6)

		; Close the libraries

.NoWin 		MOVE.L	4.W,a6			; a6 = ExecBase
		MOVE.L	IntBase(PC),a1
		JSR	_LVOCloseLibrary(a6)
.NoInt		MOVE.L	GadBase(PC),a1
		JSR	_LVOCloseLibrary(a6)

.NoGad		MOVEQ	#0,d0
		RTS



.GadName	DC.B	"gadtools.library",0
.IntName	DC.B	"intuition.library",0
		EVEN


;=================================================================
;
;=================================================================

OpenWindow:	MOVE.L	IntBase(PC),a6		; a6 = IntBase
		SUB.L	a0,a0			; APTR NewWindow = null
		LEA.L	.Tags(PC),a1		; APTR taglist
		JSR	_LVOOpenWindowTagList(a6)
		MOVE.L	d0,MainWin		; Sets Z-flag when null
		RTS


.Tags		DC.L	WA_Width,200
		DC.L	WA_Height,100
		DC.L	WA_Title,.Title
		DC.L	WA_IDCMP,IDCMP_CLOSEWINDOW|IDCMP_MENUPICK|IDCMP_RAWKEY|IDCMP_REFRESHWINDOW|BUTTONIDCMP|CYCLEIDCMP
		DC.L	WA_DragBar,1
		DC.L	WA_DepthGadget,1
		DC.L	WA_Activate,1
		DC.L	WA_CloseGadget,1
		DC.L	WA_NewLookMenus,1
		DC.L	TAG_END

.Title		DC.B	"Hello World!",0
		EVEN
		

;=================================================================
;
;=================================================================

CreateMenu:	MOVE.L	GadBase(PC),a6		; a6 = GadBase

		; Create the menu structs in memory

		LEA.L	.NMArray(PC),a0		; APTR NewMenu array
		SUB.L	a1,a1			; APTR Taglist = null
		JSR	CreateMenus(a6)
		MOVE.L	d0,WinMenu		; APTR Intuition menu
		BEQ.B	.NoMenu			; Null means error

		; Set sizes and locations in menu

		MOVE.L	d0,a0			; APTR Menu
		MOVE.L	VisualInfo(PC),a1	; APTR VistualInfo
		SUB.L	a2,a2			; APTR Taglist = null
		JSR	LayoutMenus(a6)
		TST.L	d0			; ULONG Success
		BEQ.B	.NoMenu			; Skip if there was an error

		; Attach the menu to the window

		MOVE.L	IntBase(PC),a6		; a6 = IntBase
		MOVE.L	MainWin(PC),a0		; APTR Window
		MOVE.L	WinMenu(PC),a1		; APTR Menu
		JSR	_LVOSetMenuStrip(a6)
.NoMenu		RTS


; The array of GadTools NewMenu structs

.NMArray	DC.B	NM_TITLE,0		;Type Menu and word alignment
		DC.L	.ProjectTxt		;APTR Label
		DC.L	0			;APTR Keyboard code
		DC.W	0			;UWORD Flags.
		DC.L	0			;ULONG Mutual exclude.
		DC.L	0			;ULONG Userdata.

		DC.B	NM_ITEM,0		;Type Menu and word alignment
		DC.L	.AboutTxt		;APTR Label
		DC.L	.AboutTxt		;APTR Keyboard code
		DC.W	0			;UWORD Flags.
		DC.L	0			;ULONG Mutual exclude.
		DC.L	CMD_ABOUT		;ULONG Userdata.

		DC.B	NM_ITEM,0		;Type Menu and word alignment
		DC.L	NM_BARLABEL		;APTR Label
		DC.L	0			;APTR Keyboard code
		DC.W	0			;UWORD Flags.
		DC.L	0			;ULONG Mutual exclude.
		DC.L	0			;ULONG Userdata.

		DC.B	NM_ITEM,0		;Type Menu and word alignment
		DC.L	.QuitTxt		;APTR Label
		DC.L	.QuitTxt		;APTR Keyboard code
		DC.W	0			;UWORD Flags.
		DC.L	0			;ULONG Mutual exclude.
		DC.L	CMD_QUIT		;ULONG Userdata.

		DC.B	NM_TITLE,0		;Type Menu and word alignment
		DC.L	.OptionsTxt		;APTR Label
		DC.L	0			;APTR Keyboard code
		DC.W	0			;UWORD Flags.
		DC.L	0			;ULONG Mutual exclude.
		DC.L	0			;ULONG Userdata.

		DC.B	NM_ITEM,0		;Type Menu and word alignment
		DC.L	.OptHighTxt		;APTR Label
		DC.L	0			;APTR Keyboard code
		DC.W	CHECKIT|MENUTOGGLE|CHECKED	;UWORD Flags.
		DC.L	6			;ULONG Mutual exclude.
		DC.L	CMD_OPTHIGH		;ULONG Userdata.

		DC.B	NM_ITEM,0		;Type Menu and word alignment
		DC.L	.OptMidTxt		;APTR Label
		DC.L	0			;APTR Keyboard code
		DC.W	CHECKIT|MENUTOGGLE	;UWORD Flags.
		DC.L	5			;ULONG Mutual exclude.
		DC.L	CMD_OPTMID		;ULONG Userdata.

		DC.B	NM_ITEM,0		;Type Menu and word alignment
		DC.L	.OptLowTxt		;APTR Label
		DC.L	0			;APTR Keyboard code
		DC.W	CHECKIT|MENUTOGGLE	;UWORD Flags.
		DC.L	3			;ULONG Mutual exclude.
		DC.L	CMD_OPTLOW		;ULONG Userdata.

		DC.L	NM_END

; Strings that are part of the menu

.ProjectTxt	DC.B	"Project",0
.AboutTxt	DC.B	"About...",0
.QuitTxt	DC.B	"Quit",0
.OptionsTxt	DC.B	"Options",0
.OptHighTxt	DC.B	"High",0
.OptMidTxt	DC.B	"Mid",0
.OptLowTxt	DC.B	"Low",0
		EVEN


;=================================================================
;
;=================================================================

CreateGadgets:	MOVE.L	GadBase(PC),a6		; a6 = GadBase

		LEA.L	WinGGList(PC),a0	; APTR to gadget list
		JSR	CreateContext(a6)
		MOVEA.L	d0,a0			; APTR Gadget
		TST.L	d0			; Is the result null?
		BEQ.B	.ErrOut			; Yes. Thats is an error

		MOVE.L	VisualInfo(PC),d7
		LEA.L	.GGArray(PC),a5		; APTR information array
		LEA.L	MyGadgets(PC),a4	; APTR GG Pointer storage

.NextGG		MOVE.L	(a5)+,d0		; ULONG Kind
		BEQ.B	.Done			; Zero kind? End of array
		MOVE.L	(a5)+,a1		; APTR NewGad
		MOVE.L	d7,gng_VisualInfo(a1)	; Place VisualInfo in NewGad
		MOVE.L	(a5)+,a2		; APTR taglist
		JSR	CreateGadget(a6)
		TST.L	d0			; Result is null?
		BEQ.B	.ErrOut			; Yes. bail out
		MOVEA.L	d0,a0			; APTR Gadget
		MOVE.L	a0,(a4)+		; Store pointer for later
		BRA.b	.NextGG

.Done		MOVE.L	IntBase(PC),a6		; a6 = IntBase
		MOVE.L	MainWin(PC),a0		; APTR Window
		MOVE.L	WinGGList(PC),a1	; APTR Gadget List
		MOVEQ	#0,d0			; UWORD Position
		MOVEQ	#-1,d1			; WORD Numgad (-1 = all)
		JSR	_LVOAddGList(a6)

		MOVE.L	WinGGList(PC),a0	; APTR Gadget List
		MOVE.L	MainWin(PC),a1		; APTR Window
		MOVEQ	#-1,d0			; WORD Numgad (-1 = all)
		JSR	_LVORefreshGList(a6)

.ErrOut		RTS


; Array of all gadgets that need to be created

.GGArray	DC.L	BUTTON_KIND,.QuitGG,0
		DC.L	BUTTON_KIND,.AboutGG,0
		DC.L	CYCLE_KIND,.OptionsGG,.OptionsTL
		DC.L	0

; The individual structs and taglists (where required)

.QuitGG		DC.W	100,78,85,14
		DC.L	.QuitTxt,0
		DC.W	1
		DC.L	0
		DC.L	0,CMD_QUIT

.AboutGG	DC.W	100,20,85,14
		DC.L	.AboutTxt,0
		DC.W	2
		DC.L	0
		DC.L	0,CMD_ABOUT

.OptionsGG	DC.W	100,35,85,14
		DC.L	.OptionsTxt,0
		DC.W	3
		DC.L	0
		DC.L	0,CMD_OPTIONS
.OptionsTL	DC.L	GTCY_Labels,.OptionsLabels
		DC.L	TAG_DONE
.OptionsLabels	DC.L	.OptLab1,.OptLab2,.OptLab3,0


; The strings for the gadgets

.QuitTxt	DC.B	"Quit",0
.AboutTxt	DC.B	"about..",0
.OptionsTxt	DC.B	"Options",0
.OptLab1	DC.B	"High",0
.OptLab2	DC.B	"Mid",0
.OptLab3	DC.B	"Low",0
		EVEN
; Array to receive the individual gadget pointers

MyGadgets:	DC.L	0,0,0



;=================================================================
; The meain window message loop
;=================================================================

MainMsgLoop:	MOVE.L	MainWin(PC),a0		; APTR Window
		MOVE.L	wd_UserPort(a0),.WinPort; APTR MsgPort
.Loop		MOVE.W	Command(PC),d0		; UWORD Command + Source
		ANDI.W	#CMD_MASK,d0		; Keep only the command
		CMPI.W	#CMD_QUIT,d0		; Need to end program?
		BNE.B	.WaitMsg		; No? Wait for a message
		RTS

		; Sleep until a message arrives

.WaitMsg	MOVE.L	4.W,a6			; a6 = ExecBase
		MOVE.L	.WinPort(PC),a0		; APTR MsgPort
		JSR	_LVOWaitPort(a6)

		; Retrieve the message

.NextMsg	MOVE.L	GadBase(PC),a6		; a6 = GadBase
		MOVE.L	.WinPort(PC),a0		; APTR msgPort
		JSR	GT_GetIMsg(a6)
		MOVE.L	d0,.Msg			; APTR IntuiMessage
		BEQ.B	.Loop			; None? Wait for the next one

		; Process the message depending on class		

		MOVEA.L	d0,a1
		MOVE.L	im_Class(a1),d7		; ULONG Message class
		CMPI.L	#IDCMP_MENUPICK,d7	; User picked a menu?
		BEQ.B	.MenuPick		; Yes. Deal with it
		CMPI.L	#IDCMP_GADGETUP,d7	; User clicked a gadget?
		BEQ.B	.GadgetUp		; Yes. Deal with it
		CMPI.L	#IDCMP_RAWKEY,d7	; User pressed a key?
		BEQ.W	.RawKey			; Yes. Deal with it
		CMPI.L	#IDCMP_CLOSEWINDOW,d7	; User clicked close?
		BNE.B	.MsgDone		; No. Continue
		MOVE.W	#CMD_QUIT,Command	; Yes. Prepare to close

		; Reply the message

.MsgDone	MOVE.L	GadBase(PC),a6		; a6 = GadBase
		MOVE.L	.Msg(PC),a1		; APTR IntuiMsg
		JSR	GT_ReplyIMsg(a6)

		; Check what command we have

		MOVE.W	Command(PC),d0		; UWORD Command + Source
		ANDI.W	#CMD_MASK,d0		; Keep only the command
		CMPI.W	#CMD_OPTIONS,d0		; Need to update the option?
		BNE.B	.NotOptions		; No? Skip to next command
		BSR.W	UpdateOptions		; Yes? Update the options shown
		BRA.B	.NextMsg
.NotOptions	CMPI.W	#CMD_ABOUT,d0		; Need to show about?
		BNE.B	.NotAbout		; No. Skip to the next check
		BSR.B	About
		CLR.W	Command			; Command has been processed
.NotAbout	BRA.B	.NextMsg

; Processing IDCMP_MENUPICK

.MenuPick	MOVE.W	im_Code(a1),d0		; UWORD Menu number
		BEQ.B	.MsgDone		; Zero? No menu
		MOVE.L	WinMenu(PC),a0		; APTR Menu
		MOVE.L	IntBase(PC),a6		; a6 = IntBase
		JSR	_LVOItemAddress(a6)
		TST.L	d0			; Check the resulting address
		BEQ.B	.MsgDone		; Null? No menu found
		MOVEA.L	d0,a0			; APTR MenuItem
		MOVE.L	mi_SIZEOF(a0),d0	; Userdata stored after struct
		ADDI.W	#SRC_MENU,d0		; Add source of command
		MOVE.W	d0,Command		; Store command
		BRA.B	.MsgDone


; Processing IDCMP_GADGETUP

.GadgetUp	MOVE.L	im_IAddress(a1),a0	; APTR originating Gadget
		MOVE.L	gg_UserData(a0),d0	; ULONG Command
		CMPI.W	#CMD_OPTIONS,d0		; Was it the options gadget?
		BNE.B	.NotOptionsGG		; No. Skip the next part 
		ADD.W	im_Code(a1),d0		; Add selected option ID.
.NotOptionsGG	ADDI.W	#SRC_GADGET,d0		; Add source of command
		MOVE.W	d0,Command		; Set the command	
		BRA.B	.MsgDone


; Processing IDCMP_RAWKEY

.RawKey		MOVE.W	im_Code(a1),d0		; Get the keycode
		CMPI.B	#$c5,d0			; The 'Esc' key?
		BNE.B	.MsgDone		; No. Ignore the key.
		MOVE.W	#CMD_QUIT,Command	; Yes. Prepare to close	
		BRA.W	.MsgDone

; Local variables

.Msg		DC.L	0
.WinPort	DC.L	0


;=================================================================
;=================================================================

About:		MOVE.L	IntBase(PC),a6		; a6 = IntBase
		MOVE.L	MainWin(PC),a0		; APTR Window
		LEA.L	.EasyReq(PC),a1		; APTR EasyReq struct
		LEA.L	.IDCMP(PC),a2		; APTR IDCMP flags
		SUB.L	a3,a3			; APTR Arguments = null
		JSR	_LVOEasyRequestArgs(a6)
		RTS


.EasyReq	DC.L	20	; ULONG StructSize
		DC.L	0	; ULONG Flags
		DC.L	0	; APTR Title string
		DC.L	.Msg	; APTR Text format
		DC.L	.GGFmt	; APTR gadget format		
.IDCMP		DC.L	0
.GGFmt		DC.B	"Close",0
.Msg:		DC.B	"This is the About message!",0
		EVEN


;=================================================================
;=================================================================

UpdateOptions:	MOVE.W	Command(PC),d7		; UWORD Command + Source + Option
		MOVE.W	d7,d0
		ANDI.W	#SRC_MASK,d0		; UWORD Source
		CMPI.W	#SRC_GADGET,d0		; Came from a gadget?
		BEQ.B	.UpdateMenu		; Yes. Update only the menu

		MOVE.L	MyGadgets+8(PC),a0	; APTR Cycle gadget
		MOVE.L	MainWin(PC),a1		; APTR Window
		SUB.L	a2,a2			; APTR Requester = null		
		LEA.L	.UpdateTags(PC),a3	; APTR Taglist
		ANDI.W	#$F,d7			; UBYTE Keep the option ID
		MOVE.W	d7,6(a3)		; Place in taglist
		JSR	GT_SetGadgetAttrs(a6)

		RTS

.UpdateTags:	DC.L	GTCY_Active,0,TAG_END


.UpdateMenu	MOVE.L	IntBase(PC),a6		; a6 = IntBase
		ANDI.W	#~SRC_MASK,d7		; Remove the source

		; Remove the menu from the window.

		MOVE.L	MainWin(PC),a0		; APTR Window
		JSR	_LVOClearMenuStrip(a6)

		; Get the address of the first option item

		MOVEQ	#1,d0			; UWORD Menunumber
		MOVE.L	WinMenu(PC),a0		; APTR Menu
		JSR	_LVOItemAddress(a6)

		; Set/clear the CHECKED flag for each item as needed

.NextItem	MOVE.L	d0,a0			; APTR MenuItem
		TST.L	d0			; Null?
		BEQ.B	.MenuEnd		; Yes. No more items
		MOVE.L	mi_SIZEOF(a0),d1	; Get the item's command
		CMP.L	d7,d1			; Same as current command?
		BEQ.B	.SetCheck
		ANDI.W	#~CHECKED,mi_Flags(a0)	; Clear the CHECKED flag
		BRA.B	.CheckDone
.SetCheck	ORI.W	#CHECKED,mi_Flags(a0)	; Set the CHECKED flag.
.CheckDone	MOVE.L	mi_NextItem(a0),d0	; APTR Next MenuItem
		BRA.B	.NextItem		; Keep processing.

		; Place the modified menu back on the window
				
.MenuEnd	MOVE.L	MainWin(PC),a0		; APTR Window
		MOVE.L	WinMenu(PC),a1		; APTR Menu
		JSR	_LVOResetMenuStrip(a6)

		RTS



;=================================================================
; Globally used variables
;=================================================================


Command:	DC.W	CMD_NONE
MainWin:	DC.L	0
WinMenu:	DC.L	0
WinGGList:	DC.L	0
GadBase:	DC.L	0
IntBase:	DC.L	0
VisualInfo	DC.L	0


;-----------------------------------------------------------------

